==> nextcloud-27.0.2.tar.bz2: nextcloud/apps/user_status/l10n/fi.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Viimeisimmät tilatiedot",
    "In a meeting" : "Tapaamisessa",
    "Commuting" : "Työmatkalla",
    "Out sick" : "Sairaana",
    "Vacationing" : "Lomailemassa",
    "Working remotely" : "Etätyössä",
    "In a call" : "Puhelussa",
    "User status" : "Käyttäjän tilatieto",
    "View profile" : "Näytä profiili",
    "Clear status after" : "Tyhjennä tilatieto",
    "Emoji for your status message" : "Emoji tilaviestiisi",
    "What is your status?" : "Mikä on tilatietosi?",
    "Predefined statuses" : "Ennalta määritellyt tilatiedot",
    "Previously set" : "Aiemmin asetettu",
    "Reset status" : "Palauta tilatieto",
    "Set status" : "Aseta tilatieto",
    "Online status" : "Online-tila",
    "Status message" : "Tilaviesti",
    "Your status was set automatically" : "Tilatietosi asetettiin automaattisesti",
    "Clear status message" : "Tyhjennä tilaviesti",
    "Set status message" : "Aseta tilaviesti",
    "Reset status to \"{icon} {message}\"" : "Palauta tilatiedoksi \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Palauta tilatiedoksi \"{message}\"",
    "Reset status to \"{icon}\"" : "Palauta tilatiedoksi \"{icon}\"",
    "There was an error saving the status" : "Tilatiedon tallentamisessa tapahtui virhe",
    "There was an error clearing the status" : "Tilatietoa tyhjentäessä tapahtui virhe",
    "There was an error reverting the status" : "Tilatietoa palauttaessa tapahtui virhe",
    "No recent status changes" : "Ei viimeisimpiä tilatietomuutoksia",
    "Away" : "Poissa",
    "Do not disturb" : "Älä häiritse",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Älä tyhjennä",
    "Today" : "Tänään",
    "This week" : "Tällä viikolla",
    "Online" : "Paikalla",
    "Invisible" : "Näkymätön",
    "Offline" : "Poissa",
    "There was an error saving the new status" : "Uuden tilatiedon tallentamisessa tapahtui virhe",
    "30 minutes" : "30 minuuttia",
    "1 hour" : "1 tunti",
    "4 hours" : "4 tuntia",
    "Mute all notifications" : "Mykistä kaikki ilmoitukset",
    "Appear offline" : "Näytä olevan poissa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/user_status/l10n/fi.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Viimeisimmät tilatiedot",
    "No recent status changes" : "Ei viimeisimpiä tilatietomuutoksia",
    "In a meeting" : "Tapaamisessa",
    "Commuting" : "Työmatkalla",
    "Out sick" : "Sairaana",
    "Vacationing" : "Lomailemassa",
    "Out of office" : "Poissa työpaikalta",
    "Working remotely" : "Etätyössä",
    "In a call" : "Puhelussa",
    "User status" : "Käyttäjän tilatieto",
    "Clear status after" : "Tyhjennä tilatieto",
    "Emoji for your status message" : "Emoji tilaviestiisi",
    "What is your status?" : "Mikä on tilatietosi?",
    "Predefined statuses" : "Ennalta määritellyt tilatiedot",
    "Previously set" : "Aiemmin asetettu",
    "Reset status" : "Palauta tilatieto",
    "Reset status to \"{icon} {message}\"" : "Palauta tilatiedoksi \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Palauta tilatiedoksi \"{message}\"",
    "Reset status to \"{icon}\"" : "Palauta tilatiedoksi \"{icon}\"",
    "There was an error saving the status" : "Tilatiedon tallentamisessa tapahtui virhe",
    "There was an error clearing the status" : "Tilatietoa tyhjentäessä tapahtui virhe",
    "There was an error reverting the status" : "Tilatietoa palauttaessa tapahtui virhe",
    "Online status" : "Online-tila",
    "Status message" : "Tilaviesti",
    "Set absence period" : "Aseta poissaoloaika",
    "Set absence period and replacement" : "Aseta poissaoloaika ja sijainen",
    "Your status was set automatically" : "Tilatietosi asetettiin automaattisesti",
    "Clear status message" : "Tyhjennä tilaviesti",
    "Set status message" : "Aseta tilaviesti",
    "Don't clear" : "Älä tyhjennä",
    "Today" : "Tänään",
    "This week" : "Tällä viikolla",
    "Online" : "Paikalla",
    "Away" : "Poissa",
    "Do not disturb" : "Älä häiritse",
    "Invisible" : "Näkymätön",
    "Offline" : "Poissa",
    "Set status" : "Aseta tilatieto",
    "There was an error saving the new status" : "Uuden tilatiedon tallentamisessa tapahtui virhe",
    "30 minutes" : "30 minuuttia",
    "1 hour" : "1 tunti",
    "4 hours" : "4 tuntia",
    "Busy" : "Varattu",
    "Mute all notifications" : "Mykistä kaikki ilmoitukset",
    "Appear offline" : "Näytä olevan poissa"
},
"nplurals=2; plural=(n != 1);");
